==> nlme_3.1-7.tar.gz: nlme/man/Variogram.corLin.Rd <==
% $Id: Variogram.corLin.Rd,v 1.4 2000/07/03 18:22:46 bates Exp $
\name{Variogram.corLin}
\title{Calculate Semi-variogram for a corLin Object}
\usage{
Variogram(object, distance, sig2, length.out)
}
\alias{Variogram.corLin}
\arguments{
  \item{object}{an object inheriting from class \code{corLin},
    representing an Linear spatial correlation structure.}
  \item{distance}{an optional numeric vector with the distances at
    which the semi-variogram is to be calculated. Defaults to
    \code{NULL}, in which case a sequence of length \code{length.out}
    between the minimum and maximum values of
    \code{getCovariate(object)} is used.}
  \item{sig2}{an optional numeric value representing the process
    variance. Defaults to \code{1}.}
  \item{length.out}{an optional integer specifying the length of the
    sequence of distances to be used for calculating the semi-variogram,
    when \code{distance = NULL}. Defaults to \code{50}.}
}
\description{
  This method function calculates the semi-variogram values
  corresponding to the Linear correlation model, using the estimated
  coefficients corresponding to \code{object}, at the distances defined
  by \code{distance}.
}
\value{
  a data frame with columns \code{variog} and \code{dist} representing,
  respectively, the semi-variogram values and the corresponding
  distances. The returned value inherits from class \code{Variogram}. 
}
\references{
  Cressie, N.A.C. (1993), "Statistics for Spatial Data", J. Wiley & Sons.
}  
\author{Jose Pinheiro and Douglas Bates}

\seealso{\code{\link{corLin}}, \code{\link{plot.Variogram}}}
\examples{
data(BodyWeight)
cs1 <- corLin(15, form = ~ Time | Rat)
cs1 <- initialize(cs1, BodyWeight)
Variogram(cs1)[1:10,]
}
\keyword{models}

==> nlme_3.1-22.tar.gz: nlme/man/Variogram.corLin.Rd <==
% $Id: Variogram.corLin.Rd,v 1.6 2001/10/30 20:51:14 bates Exp $
\name{Variogram.corLin}
\title{Calculate Semi-variogram for a corLin Object}
\usage{
\method{Variogram}{corLin}(object, distance, sig2, length.out, \dots)
}
\alias{Variogram.corLin}
\arguments{
  \item{object}{an object inheriting from class \code{corLin},
    representing an Linear spatial correlation structure.}
  \item{distance}{an optional numeric vector with the distances at
    which the semi-variogram is to be calculated. Defaults to
    \code{NULL}, in which case a sequence of length \code{length.out}
    between the minimum and maximum values of
    \code{getCovariate(object)} is used.}
  \item{sig2}{an optional numeric value representing the process
    variance. Defaults to \code{1}.}
  \item{length.out}{an optional integer specifying the length of the
    sequence of distances to be used for calculating the semi-variogram,
    when \code{distance = NULL}. Defaults to \code{50}.}
 \item{\dots}{some methods for this generic require additional
    arguments.  None are used in this method.} 
}
\description{
  This method function calculates the semi-variogram values
  corresponding to the Linear correlation model, using the estimated
  coefficients corresponding to \code{object}, at the distances defined
  by \code{distance}.
}
\value{
  a data frame with columns \code{variog} and \code{dist} representing,
  respectively, the semi-variogram values and the corresponding
  distances. The returned value inherits from class \code{Variogram}. 
}
\references{
  Cressie, N.A.C. (1993), "Statistics for Spatial Data", J. Wiley & Sons.
}  
\author{Jose Pinheiro and Douglas Bates}

\seealso{\code{\link{corLin}}, \code{\link{plot.Variogram}}}
\examples{
data(BodyWeight)
cs1 <- corLin(15, form = ~ Time | Rat)
cs1 <- initialize(cs1, BodyWeight)
Variogram(cs1)[1:10,]
}
\keyword{models}
